Class: FattureInCloud_Ruby_Sdk::DocumentTemplate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FattureInCloud_Ruby_Sdk::DocumentTemplate
- Defined in:
- lib/fattureincloud_ruby_sdk/models/document_template.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#author ⇒ Object
Template author.
-
#can_disable_watermark ⇒ Object
Can disable watermark.
-
#content ⇒ Object
Template definition content.
-
#id ⇒ Object
Template id.
-
#name ⇒ Object
Template name.
-
#privacy ⇒ Object
Template privacy.
-
#supports_custom_taxable ⇒ Object
Supports custom taxable.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DocumentTemplate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DocumentTemplate
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FattureInCloud_Ruby_Sdk::DocumentTemplate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FattureInCloud_Ruby_Sdk::DocumentTemplate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'privacy') self.privacy = attributes[:'privacy'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'can_disable_watermark') self.can_disable_watermark = attributes[:'can_disable_watermark'] end if attributes.key?(:'author') self. = attributes[:'author'] end if attributes.key?(:'content') self.content = attributes[:'content'] end if attributes.key?(:'supports_custom_taxable') self.supports_custom_taxable = attributes[:'supports_custom_taxable'] end end |
Instance Attribute Details
#author ⇒ Object
Template author
33 34 35 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 33 def @author end |
#can_disable_watermark ⇒ Object
Can disable watermark
30 31 32 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 30 def can_disable_watermark @can_disable_watermark end |
#content ⇒ Object
Template definition content
36 37 38 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 36 def content @content end |
#id ⇒ Object
Template id
19 20 21 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 19 def id @id end |
#name ⇒ Object
Template name
27 28 29 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 27 def name @name end |
#privacy ⇒ Object
Template privacy
22 23 24 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 22 def privacy @privacy end |
#supports_custom_taxable ⇒ Object
Supports custom taxable
39 40 41 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 39 def supports_custom_taxable @supports_custom_taxable end |
#type ⇒ Object
Returns the value of attribute type.
24 25 26 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 24 def type @type end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 225 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end when :Hash value else # model # models (e.g. Pet) or oneOf klass = FattureInCloud_Ruby_Sdk.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 64 def self.attribute_map { :'id' => :'id', :'privacy' => :'privacy', :'type' => :'type', :'name' => :'name', :'can_disable_watermark' => :'can_disable_watermark', :'author' => :'author', :'content' => :'content', :'supports_custom_taxable' => :'supports_custom_taxable' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 201 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 102 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 88 def self.openapi_types { :'id' => :'Integer', :'privacy' => :'String', :'type' => :'TemplateType', :'name' => :'String', :'can_disable_watermark' => :'Boolean', :'author' => :'String', :'content' => :'String', :'supports_custom_taxable' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 173 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && privacy == o.privacy && type == o.type && name == o.name && can_disable_watermark == o.can_disable_watermark && == o. && content == o.content && supports_custom_taxable == o.supports_custom_taxable end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 298 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 194 def hash [id, privacy, type, name, can_disable_watermark, , content, supports_custom_taxable].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 158 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
274 275 276 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 274 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
268 269 270 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 268 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
166 167 168 169 |
# File 'lib/fattureincloud_ruby_sdk/models/document_template.rb', line 166 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |