Class: FattureInCloud_Ruby_Sdk::Email

Inherits:
Object
  • Object
show all
Defined in:
lib/fattureincloud_ruby_sdk/models/email.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Email

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 142

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FattureInCloud_Ruby_Sdk::Email` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FattureInCloud_Ruby_Sdk::Email`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'sent_date')
    self.sent_date = attributes[:'sent_date']
  end

  if attributes.key?(:'errors_count')
    self.errors_count = attributes[:'errors_count']
  end

  if attributes.key?(:'error_log')
    self.error_log = attributes[:'error_log']
  end

  if attributes.key?(:'from_email')
    self.from_email = attributes[:'from_email']
  end

  if attributes.key?(:'from_name')
    self.from_name = attributes[:'from_name']
  end

  if attributes.key?(:'to_email')
    self.to_email = attributes[:'to_email']
  end

  if attributes.key?(:'to_name')
    self.to_name = attributes[:'to_name']
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'copy_to')
    self.copy_to = attributes[:'copy_to']
  end

  if attributes.key?(:'recipient_status')
    self.recipient_status = attributes[:'recipient_status']
  end

  if attributes.key?(:'recipient_date')
    self.recipient_date = attributes[:'recipient_date']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end
end

Instance Attribute Details

#attachmentsObject

Email attachments.



61
62
63
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 61

def attachments
  @attachments
end

#contentObject

Email content.



49
50
51
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 49

def content
  @content
end

#copy_toObject

Returns the value of attribute copy_to.



51
52
53
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 51

def copy_to
  @copy_to
end

#error_logObject

Error log.



31
32
33
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 31

def error_log
  @error_log
end

#errors_countObject

Errors count.



28
29
30
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 28

def errors_count
  @errors_count
end

#from_emailObject

Sender email.



34
35
36
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 34

def from_email
  @from_email
end

#from_nameObject

Sender name.



37
38
39
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 37

def from_name
  @from_name
end

#idObject

Email unique identifier.



20
21
22
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 20

def id
  @id
end

#kindObject

Email kind.



58
59
60
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 58

def kind
  @kind
end

#recipient_dateObject

Returns the value of attribute recipient_date.



55
56
57
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 55

def recipient_date
  @recipient_date
end

#recipient_statusObject

Returns the value of attribute recipient_status.



53
54
55
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 53

def recipient_status
  @recipient_status
end

#sent_dateObject

Email sent date.



25
26
27
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 25

def sent_date
  @sent_date
end

#statusObject

Returns the value of attribute status.



22
23
24
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 22

def status
  @status
end

#subjectObject

Email subject.



46
47
48
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 46

def subject
  @subject
end

#to_emailObject

Recipient email.



40
41
42
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 40

def to_email
  @to_email
end

#to_nameObject

Receipient email.



43
44
45
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 43

def to_name
  @to_name
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



108
109
110
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 108

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 86

def self.attribute_map
  {
    :'id' => :'id',
    :'status' => :'status',
    :'sent_date' => :'sent_date',
    :'errors_count' => :'errors_count',
    :'error_log' => :'error_log',
    :'from_email' => :'from_email',
    :'from_name' => :'from_name',
    :'to_email' => :'to_email',
    :'to_name' => :'to_name',
    :'subject' => :'subject',
    :'content' => :'content',
    :'copy_to' => :'copy_to',
    :'recipient_status' => :'recipient_status',
    :'recipient_date' => :'recipient_date',
    :'kind' => :'kind',
    :'attachments' => :'attachments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 273

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



135
136
137
138
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 135

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 113

def self.openapi_types
  {
    :'id' => :'Integer',
    :'status' => :'EmailStatus',
    :'sent_date' => :'Time',
    :'errors_count' => :'Integer',
    :'error_log' => :'String',
    :'from_email' => :'String',
    :'from_name' => :'String',
    :'to_email' => :'String',
    :'to_name' => :'String',
    :'subject' => :'String',
    :'content' => :'String',
    :'copy_to' => :'String',
    :'recipient_status' => :'EmailRecipientStatus',
    :'recipient_date' => :'Time',
    :'kind' => :'String',
    :'attachments' => :'Array<EmailAttachment>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 237

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      status == o.status &&
      sent_date == o.sent_date &&
      errors_count == o.errors_count &&
      error_log == o.error_log &&
      from_email == o.from_email &&
      from_name == o.from_name &&
      to_email == o.to_email &&
      to_name == o.to_name &&
      subject == o.subject &&
      content == o.content &&
      copy_to == o.copy_to &&
      recipient_status == o.recipient_status &&
      recipient_date == o.recipient_date &&
      kind == o.kind &&
      attachments == o.attachments
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 304

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  when :Hash
    value
  else # model
    # models (e.g. Pet) or oneOf
    klass = FattureInCloud_Ruby_Sdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 377

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 280

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


260
261
262
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 260

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



266
267
268
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 266

def hash
  [id, status, sent_date, errors_count, error_log, from_email, from_name, to_email, to_name, subject, content, copy_to, recipient_status, recipient_date, kind, attachments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



224
225
226
227
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 224

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



353
354
355
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 353

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 359

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



347
348
349
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 347

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



231
232
233
# File 'lib/fattureincloud_ruby_sdk/models/email.rb', line 231

def valid?
  true
end