Class: FattureInCloud_Ruby_Sdk::EmailData

Inherits:
Object
  • Object
show all
Defined in:
lib/fattureincloud_ruby_sdk/models/email_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EmailData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FattureInCloud_Ruby_Sdk::EmailData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FattureInCloud_Ruby_Sdk::EmailData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'recipient_email')
    self.recipient_email = attributes[:'recipient_email']
  end

  if attributes.key?(:'default_sender_email')
    self.default_sender_email = attributes[:'default_sender_email']
  end

  if attributes.key?(:'sender_emails_list')
    if (value = attributes[:'sender_emails_list']).is_a?(Array)
      self.sender_emails_list = value
    end
  end

  if attributes.key?(:'cc_email')
    self.cc_email = attributes[:'cc_email']
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'document_exists')
    self.document_exists = attributes[:'document_exists']
  end

  if attributes.key?(:'delivery_note_exists')
    self.delivery_note_exists = attributes[:'delivery_note_exists']
  end

  if attributes.key?(:'attachment_exists')
    self.attachment_exists = attributes[:'attachment_exists']
  end

  if attributes.key?(:'accompanying_invoice_exists')
    self.accompanying_invoice_exists = attributes[:'accompanying_invoice_exists']
  end

  if attributes.key?(:'default_attach_pdf')
    self.default_attach_pdf = attributes[:'default_attach_pdf']
  end
end

Instance Attribute Details

#accompanying_invoice_existsObject

If an accompanying invoice exists, this flag will be set to true



46
47
48
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 46

def accompanying_invoice_exists
  @accompanying_invoice_exists
end

#attachment_existsObject

If the document has one or more attachments, this flag will be set to true



43
44
45
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 43

def attachment_exists
  @attachment_exists
end

#bodyObject

Email body



34
35
36
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 34

def body
  @body
end

#cc_emailObject

By default is the logged company email. This is the email address to which a copy will be sent.



28
29
30
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 28

def cc_email
  @cc_email
end

#default_attach_pdfObject

If a pdf is attached, this flag will be set to true



49
50
51
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 49

def default_attach_pdf
  @default_attach_pdf
end

#default_sender_emailObject

Returns the value of attribute default_sender_email.



22
23
24
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 22

def default_sender_email
  @default_sender_email
end

#delivery_note_existsObject

If the document is a delivery note, this flag will be set to true



40
41
42
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 40

def delivery_note_exists
  @delivery_note_exists
end

#document_existsObject

If the document is not a delivery note, this flag will be set to true



37
38
39
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 37

def document_exists
  @document_exists
end

#recipient_emailObject

Recipient’s email



20
21
22
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 20

def recipient_email
  @recipient_email
end

#sender_emails_listObject

List of all emails from which the document can be sent



25
26
27
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 25

def sender_emails_list
  @sender_emails_list
end

#subjectObject

Email subject



31
32
33
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 31

def subject
  @subject
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 69

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 52

def self.attribute_map
  {
    :'recipient_email' => :'recipient_email',
    :'default_sender_email' => :'default_sender_email',
    :'sender_emails_list' => :'sender_emails_list',
    :'cc_email' => :'cc_email',
    :'subject' => :'subject',
    :'body' => :'body',
    :'document_exists' => :'document_exists',
    :'delivery_note_exists' => :'delivery_note_exists',
    :'attachment_exists' => :'attachment_exists',
    :'accompanying_invoice_exists' => :'accompanying_invoice_exists',
    :'default_attach_pdf' => :'default_attach_pdf'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 259

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 74

def self.openapi_types
  {
    :'recipient_email' => :'String',
    :'default_sender_email' => :'EmailDataDefaultSenderEmail',
    :'sender_emails_list' => :'Array<EmailDataSenderEmailsList>',
    :'cc_email' => :'String',
    :'subject' => :'String',
    :'body' => :'String',
    :'document_exists' => :'Boolean',
    :'delivery_note_exists' => :'Boolean',
    :'attachment_exists' => :'Boolean',
    :'accompanying_invoice_exists' => :'Boolean',
    :'default_attach_pdf' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      recipient_email == o.recipient_email &&
      default_sender_email == o.default_sender_email &&
      sender_emails_list == o.sender_emails_list &&
      cc_email == o.cc_email &&
      subject == o.subject &&
      body == o.body &&
      document_exists == o.document_exists &&
      delivery_note_exists == o.delivery_note_exists &&
      attachment_exists == o.attachment_exists &&
      accompanying_invoice_exists == o.accompanying_invoice_exists &&
      default_attach_pdf == o.default_attach_pdf
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 289

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = FattureInCloud_Ruby_Sdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 360

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 266

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 252

def hash
  [recipient_email, default_sender_email, sender_emails_list, cc_email, subject, body, document_exists, delivery_note_exists, attachment_exists, accompanying_invoice_exists, default_attach_pdf].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 160

def list_invalid_properties
  invalid_properties = Array.new
  if @recipient_email.nil?
    invalid_properties.push('invalid value for "recipient_email", recipient_email cannot be nil.')
  end

  if @default_sender_email.nil?
    invalid_properties.push('invalid value for "default_sender_email", default_sender_email cannot be nil.')
  end

  if @sender_emails_list.nil?
    invalid_properties.push('invalid value for "sender_emails_list", sender_emails_list cannot be nil.')
  end

  if @cc_email.nil?
    invalid_properties.push('invalid value for "cc_email", cc_email cannot be nil.')
  end

  if @subject.nil?
    invalid_properties.push('invalid value for "subject", subject cannot be nil.')
  end

  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  if @document_exists.nil?
    invalid_properties.push('invalid value for "document_exists", document_exists cannot be nil.')
  end

  if @delivery_note_exists.nil?
    invalid_properties.push('invalid value for "delivery_note_exists", delivery_note_exists cannot be nil.')
  end

  if @attachment_exists.nil?
    invalid_properties.push('invalid value for "attachment_exists", attachment_exists cannot be nil.')
  end

  if @accompanying_invoice_exists.nil?
    invalid_properties.push('invalid value for "accompanying_invoice_exists", accompanying_invoice_exists cannot be nil.')
  end

  if @default_attach_pdf.nil?
    invalid_properties.push('invalid value for "default_attach_pdf", default_attach_pdf cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 336

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 342

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



330
331
332
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 330

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/fattureincloud_ruby_sdk/models/email_data.rb', line 211

def valid?
  return false if @recipient_email.nil?
  return false if @default_sender_email.nil?
  return false if @sender_emails_list.nil?
  return false if @cc_email.nil?
  return false if @subject.nil?
  return false if @body.nil?
  return false if @document_exists.nil?
  return false if @delivery_note_exists.nil?
  return false if @attachment_exists.nil?
  return false if @accompanying_invoice_exists.nil?
  return false if @default_attach_pdf.nil?
  true
end