Class: FattureInCloud_Ruby_Sdk::IssuedDocumentExtraData

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb

Overview

Issued document extra data [TS fields follow the technical specifications provided by "Sistema Tessera Sanitaria"]

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IssuedDocumentExtraData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FattureInCloud_Ruby_Sdk::IssuedDocumentExtraData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FattureInCloud_Ruby_Sdk::IssuedDocumentExtraData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'multifatture_sent')
    self.multifatture_sent = attributes[:'multifatture_sent']
  end

  if attributes.key?(:'ts_communication')
    self.ts_communication = attributes[:'ts_communication']
  end

  if attributes.key?(:'ts_flag_tipo_spesa')
    self.ts_flag_tipo_spesa = attributes[:'ts_flag_tipo_spesa']
  end

  if attributes.key?(:'ts_pagamento_tracciato')
    self.ts_pagamento_tracciato = attributes[:'ts_pagamento_tracciato']
  end

  if attributes.key?(:'ts_tipo_spesa')
    self.ts_tipo_spesa = attributes[:'ts_tipo_spesa']
  end

  if attributes.key?(:'ts_opposizione')
    self.ts_opposizione = attributes[:'ts_opposizione']
  end

  if attributes.key?(:'ts_status')
    self.ts_status = attributes[:'ts_status']
  end

  if attributes.key?(:'ts_file_id')
    self.ts_file_id = attributes[:'ts_file_id']
  end

  if attributes.key?(:'ts_sent_date')
    self.ts_sent_date = attributes[:'ts_sent_date']
  end

  if attributes.key?(:'ts_full_amount')
    self.ts_full_amount = attributes[:'ts_full_amount']
  end

  if attributes.key?(:'imported_by')
    self.imported_by = attributes[:'imported_by']
  end

  if attributes.key?(:'debt_vat_detect')
    self.debt_vat_detect = attributes[:'debt_vat_detect']
  end

  if attributes.key?(:'revenue_detect')
    self.revenue_detect = attributes[:'revenue_detect']
  end
end

Instance Attribute Details

#debt_vat_detectObject

Issued document debt VAT detect



52
53
54
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 52

def debt_vat_detect
  @debt_vat_detect
end

#imported_byObject

Issued document imported by software



49
50
51
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 49

def imported_by
  @imported_by
end

#multifatture_sentObject

Returns the value of attribute multifatture_sent.



19
20
21
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 19

def multifatture_sent
  @multifatture_sent
end

#revenue_detectObject

Issued document revenue detect



55
56
57
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 55

def revenue_detect
  @revenue_detect
end

#ts_communicationObject

Send issued document to "Sistema Tessera Sanitaria"



22
23
24
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 22

def ts_communication
  @ts_communication
end

#ts_file_idObject

Issued document ts file id



40
41
42
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 40

def ts_file_id
  @ts_file_id
end

#ts_flag_tipo_spesaObject

Issued document ts "tipo spesa" [TK, FC, FV, SV,SP, AD, AS, ECG, SR]



25
26
27
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 25

def ts_flag_tipo_spesa
  @ts_flag_tipo_spesa
end

#ts_full_amountObject

Issued document ts total amount



46
47
48
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 46

def ts_full_amount
  @ts_full_amount
end

#ts_opposizioneObject

Issued document ts "opposizione"



34
35
36
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 34

def ts_opposizione
  @ts_opposizione
end

#ts_pagamento_tracciatoObject

Issued document ts traced payment



28
29
30
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 28

def ts_pagamento_tracciato
  @ts_pagamento_tracciato
end

#ts_sent_dateObject

Issued document ts sent date



43
44
45
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 43

def ts_sent_date
  @ts_sent_date
end

#ts_statusObject

Issued document ts status



37
38
39
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 37

def ts_status
  @ts_status
end

#ts_tipo_spesaObject

Can be [ ‘TK’, ‘FC’, ‘FV’, ‘SV’, ‘SP’, ‘AD’, ‘AS’, ‘SR’, ‘CT’, ‘PI’, ‘IC’, ‘AA’ ]. Refer to the technical specifications to learn more.



31
32
33
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 31

def ts_tipo_spesa
  @ts_tipo_spesa
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 267

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  when :Hash
    value
  else # model
    # models (e.g. Pet) or oneOf
    klass = FattureInCloud_Ruby_Sdk.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 58

def self.attribute_map
  {
    :'multifatture_sent' => :'multifatture_sent',
    :'ts_communication' => :'ts_communication',
    :'ts_flag_tipo_spesa' => :'ts_flag_tipo_spesa',
    :'ts_pagamento_tracciato' => :'ts_pagamento_tracciato',
    :'ts_tipo_spesa' => :'ts_tipo_spesa',
    :'ts_opposizione' => :'ts_opposizione',
    :'ts_status' => :'ts_status',
    :'ts_file_id' => :'ts_file_id',
    :'ts_sent_date' => :'ts_sent_date',
    :'ts_full_amount' => :'ts_full_amount',
    :'imported_by' => :'imported_by',
    :'debt_vat_detect' => :'debt_vat_detect',
    :'revenue_detect' => :'revenue_detect'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 106

def self.openapi_nullable
  Set.new([
    :'multifatture_sent',
    :'ts_communication',
    :'ts_flag_tipo_spesa',
    :'ts_pagamento_tracciato',
    :'ts_tipo_spesa',
    :'ts_opposizione',
    :'ts_status',
    :'ts_file_id',
    :'ts_sent_date',
    :'ts_full_amount',
    :'imported_by',
    :'debt_vat_detect',
    :'revenue_detect'
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 87

def self.openapi_types
  {
    :'multifatture_sent' => :'Integer',
    :'ts_communication' => :'Boolean',
    :'ts_flag_tipo_spesa' => :'Float',
    :'ts_pagamento_tracciato' => :'Boolean',
    :'ts_tipo_spesa' => :'String',
    :'ts_opposizione' => :'Boolean',
    :'ts_status' => :'Integer',
    :'ts_file_id' => :'String',
    :'ts_sent_date' => :'Date',
    :'ts_full_amount' => :'Boolean',
    :'imported_by' => :'String',
    :'debt_vat_detect' => :'Boolean',
    :'revenue_detect' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      multifatture_sent == o.multifatture_sent &&
      ts_communication == o.ts_communication &&
      ts_flag_tipo_spesa == o.ts_flag_tipo_spesa &&
      ts_pagamento_tracciato == o.ts_pagamento_tracciato &&
      ts_tipo_spesa == o.ts_tipo_spesa &&
      ts_opposizione == o.ts_opposizione &&
      ts_status == o.ts_status &&
      ts_file_id == o.ts_file_id &&
      ts_sent_date == o.ts_sent_date &&
      ts_full_amount == o.ts_full_amount &&
      imported_by == o.imported_by &&
      debt_vat_detect == o.debt_vat_detect &&
      revenue_detect == o.revenue_detect
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 340

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 236

def hash
  [multifatture_sent, ts_communication, ts_flag_tipo_spesa, ts_pagamento_tracciato, ts_tipo_spesa, ts_opposizione, ts_status, ts_file_id, ts_sent_date, ts_full_amount, imported_by, debt_vat_detect, revenue_detect].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



316
317
318
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 316

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 322

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



310
311
312
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 310

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end