Class: FattureInCloud_Ruby_Sdk::IssuedDocumentTotals

Inherits:
Object
  • Object
show all
Defined in:
lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IssuedDocumentTotals

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 128

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FattureInCloud_Ruby_Sdk::IssuedDocumentTotals` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FattureInCloud_Ruby_Sdk::IssuedDocumentTotals`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount_net')
    self.amount_net = attributes[:'amount_net']
  end

  if attributes.key?(:'amount_rivalsa')
    self.amount_rivalsa = attributes[:'amount_rivalsa']
  end

  if attributes.key?(:'amount_net_with_rivalsa')
    self.amount_net_with_rivalsa = attributes[:'amount_net_with_rivalsa']
  end

  if attributes.key?(:'amount_cassa')
    self.amount_cassa = attributes[:'amount_cassa']
  end

  if attributes.key?(:'taxable_amount')
    self.taxable_amount = attributes[:'taxable_amount']
  end

  if attributes.key?(:'not_taxable_amount')
    self.not_taxable_amount = attributes[:'not_taxable_amount']
  end

  if attributes.key?(:'amount_vat')
    self.amount_vat = attributes[:'amount_vat']
  end

  if attributes.key?(:'amount_gross')
    self.amount_gross = attributes[:'amount_gross']
  end

  if attributes.key?(:'taxable_amount_withholding_tax')
    self.taxable_amount_withholding_tax = attributes[:'taxable_amount_withholding_tax']
  end

  if attributes.key?(:'amount_withholding_tax')
    self.amount_withholding_tax = attributes[:'amount_withholding_tax']
  end

  if attributes.key?(:'taxable_amount_other_withholding_tax')
    self.taxable_amount_other_withholding_tax = attributes[:'taxable_amount_other_withholding_tax']
  end

  if attributes.key?(:'amount_other_withholding_tax')
    self.amount_other_withholding_tax = attributes[:'amount_other_withholding_tax']
  end

  if attributes.key?(:'stamp_duty')
    self.stamp_duty = attributes[:'stamp_duty']
  end

  if attributes.key?(:'amount_due')
    self.amount_due = attributes[:'amount_due']
  end

  if attributes.key?(:'is_enasarco_maximal_exceeded')
    self.is_enasarco_maximal_exceeded = attributes[:'is_enasarco_maximal_exceeded']
  end

  if attributes.key?(:'payments_sum')
    self.payments_sum = attributes[:'payments_sum']
  end

  if attributes.key?(:'vat_list')
    self.vat_list = attributes[:'vat_list']
  end
end

Instance Attribute Details

#amount_cassaObject

Cassa amount.



28
29
30
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 28

def amount_cassa
  @amount_cassa
end

#amount_dueObject

Total amount due.



58
59
60
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 58

def amount_due
  @amount_due
end

#amount_grossObject

Total grosas amount.



40
41
42
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 40

def amount_gross
  @amount_gross
end

#amount_netObject

Total net amount.



19
20
21
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 19

def amount_net
  @amount_net
end

#amount_net_with_rivalsaObject

Net amount with rivalsa.



25
26
27
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 25

def amount_net_with_rivalsa
  @amount_net_with_rivalsa
end

#amount_other_withholding_taxObject

Other withholding tax amount.



52
53
54
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 52

def amount_other_withholding_tax
  @amount_other_withholding_tax
end

#amount_rivalsaObject

Rivalsa amount.



22
23
24
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 22

def amount_rivalsa
  @amount_rivalsa
end

#amount_vatObject

Total vat amount.



37
38
39
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 37

def amount_vat
  @amount_vat
end

#amount_withholding_taxObject

Withholding tax amount.



46
47
48
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 46

def amount_withholding_tax
  @amount_withholding_tax
end

#is_enasarco_maximal_exceededObject

Returns the value of attribute is_enasarco_maximal_exceeded.



60
61
62
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 60

def is_enasarco_maximal_exceeded
  @is_enasarco_maximal_exceeded
end

#not_taxable_amountObject

Not taxable amount.



34
35
36
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 34

def not_taxable_amount
  @not_taxable_amount
end

#payments_sumObject

Payments sum.



63
64
65
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 63

def payments_sum
  @payments_sum
end

#stamp_dutyObject

Stamp duty value [0 if not present].



55
56
57
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 55

def stamp_duty
  @stamp_duty
end

#taxable_amountObject

Taxable amount.



31
32
33
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 31

def taxable_amount
  @taxable_amount
end

#taxable_amount_other_withholding_taxObject

Other withholding tax taxable amount.



49
50
51
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 49

def taxable_amount_other_withholding_tax
  @taxable_amount_other_withholding_tax
end

#taxable_amount_withholding_taxObject

Taxable withholding tax amount.



43
44
45
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 43

def taxable_amount_withholding_tax
  @taxable_amount_withholding_tax
end

#vat_listObject

Returns the value of attribute vat_list.



65
66
67
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 65

def vat_list
  @vat_list
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 91

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 68

def self.attribute_map
  {
    :'amount_net' => :'amount_net',
    :'amount_rivalsa' => :'amount_rivalsa',
    :'amount_net_with_rivalsa' => :'amount_net_with_rivalsa',
    :'amount_cassa' => :'amount_cassa',
    :'taxable_amount' => :'taxable_amount',
    :'not_taxable_amount' => :'not_taxable_amount',
    :'amount_vat' => :'amount_vat',
    :'amount_gross' => :'amount_gross',
    :'taxable_amount_withholding_tax' => :'taxable_amount_withholding_tax',
    :'amount_withholding_tax' => :'amount_withholding_tax',
    :'taxable_amount_other_withholding_tax' => :'taxable_amount_other_withholding_tax',
    :'amount_other_withholding_tax' => :'amount_other_withholding_tax',
    :'stamp_duty' => :'stamp_duty',
    :'amount_due' => :'amount_due',
    :'is_enasarco_maximal_exceeded' => :'is_enasarco_maximal_exceeded',
    :'payments_sum' => :'payments_sum',
    :'vat_list' => :'vat_list'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



287
288
289
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 287

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
123
124
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 119

def self.openapi_nullable
  Set.new([
    :'is_enasarco_maximal_exceeded',
    :'vat_list'
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 96

def self.openapi_types
  {
    :'amount_net' => :'Float',
    :'amount_rivalsa' => :'Float',
    :'amount_net_with_rivalsa' => :'Float',
    :'amount_cassa' => :'Float',
    :'taxable_amount' => :'Float',
    :'not_taxable_amount' => :'Float',
    :'amount_vat' => :'Float',
    :'amount_gross' => :'Float',
    :'taxable_amount_withholding_tax' => :'Float',
    :'amount_withholding_tax' => :'Float',
    :'taxable_amount_other_withholding_tax' => :'Float',
    :'amount_other_withholding_tax' => :'Float',
    :'stamp_duty' => :'Float',
    :'amount_due' => :'Float',
    :'is_enasarco_maximal_exceeded' => :'Boolean',
    :'payments_sum' => :'Float',
    :'vat_list' => :'IssuedDocumentTotalsVatList'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 250

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount_net == o.amount_net &&
      amount_rivalsa == o.amount_rivalsa &&
      amount_net_with_rivalsa == o.amount_net_with_rivalsa &&
      amount_cassa == o.amount_cassa &&
      taxable_amount == o.taxable_amount &&
      not_taxable_amount == o.not_taxable_amount &&
      amount_vat == o.amount_vat &&
      amount_gross == o.amount_gross &&
      taxable_amount_withholding_tax == o.taxable_amount_withholding_tax &&
      amount_withholding_tax == o.amount_withholding_tax &&
      taxable_amount_other_withholding_tax == o.taxable_amount_other_withholding_tax &&
      amount_other_withholding_tax == o.amount_other_withholding_tax &&
      stamp_duty == o.stamp_duty &&
      amount_due == o.amount_due &&
      is_enasarco_maximal_exceeded == o.is_enasarco_maximal_exceeded &&
      payments_sum == o.payments_sum &&
      vat_list == o.vat_list
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 317

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = FattureInCloud_Ruby_Sdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 388

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 294

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


274
275
276
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 274

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



280
281
282
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 280

def hash
  [amount_net, amount_rivalsa, amount_net_with_rivalsa, amount_cassa, taxable_amount, not_taxable_amount, amount_vat, amount_gross, taxable_amount_withholding_tax, amount_withholding_tax, taxable_amount_other_withholding_tax, amount_other_withholding_tax, stamp_duty, amount_due, is_enasarco_maximal_exceeded, payments_sum, vat_list].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 212

def list_invalid_properties
  invalid_properties = Array.new
  if @amount_net.nil?
    invalid_properties.push('invalid value for "amount_net", amount_net cannot be nil.')
  end

  if @amount_vat.nil?
    invalid_properties.push('invalid value for "amount_vat", amount_vat cannot be nil.')
  end

  if @amount_gross.nil?
    invalid_properties.push('invalid value for "amount_gross", amount_gross cannot be nil.')
  end

  if @amount_due.nil?
    invalid_properties.push('invalid value for "amount_due", amount_due cannot be nil.')
  end

  if @payments_sum.nil?
    invalid_properties.push('invalid value for "payments_sum", payments_sum cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



364
365
366
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 364

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 370

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



358
359
360
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 358

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



239
240
241
242
243
244
245
246
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_totals.rb', line 239

def valid?
  return false if @amount_net.nil?
  return false if @amount_vat.nil?
  return false if @amount_gross.nil?
  return false if @amount_due.nil?
  return false if @payments_sum.nil?
  true
end