Class: FattureInCloud_Ruby_Sdk::PaymentMethod
- Inherits:
-
Object
- Object
- FattureInCloud_Ruby_Sdk::PaymentMethod
- Defined in:
- lib/fattureincloud_ruby_sdk/models/payment_method.rb
Instance Attribute Summary collapse
-
#bank_beneficiary ⇒ Object
Bank beneficiary.
-
#bank_iban ⇒ Object
Bank iban.
-
#bank_name ⇒ Object
Bank name.
-
#default_payment_account ⇒ Object
Returns the value of attribute default_payment_account.
-
#details ⇒ Object
Method details rows.
-
#ei_payment_method ⇒ Object
EInvoice payment method.
-
#id ⇒ Object
Unique identifier.
-
#is_default ⇒ Object
Determines if this is the default payment method.
-
#name ⇒ Object
Name of the payment method.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PaymentMethod
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PaymentMethod
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FattureInCloud_Ruby_Sdk::PaymentMethod` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FattureInCloud_Ruby_Sdk::PaymentMethod`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = 'standard' end if attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] end if attributes.key?(:'default_payment_account') self.default_payment_account = attributes[:'default_payment_account'] end if attributes.key?(:'details') if (value = attributes[:'details']).is_a?(Array) self.details = value end end if attributes.key?(:'bank_iban') self.bank_iban = attributes[:'bank_iban'] end if attributes.key?(:'bank_name') self.bank_name = attributes[:'bank_name'] end if attributes.key?(:'bank_beneficiary') self.bank_beneficiary = attributes[:'bank_beneficiary'] end if attributes.key?(:'ei_payment_method') self.ei_payment_method = attributes[:'ei_payment_method'] end end |
Instance Attribute Details
#bank_beneficiary ⇒ Object
Bank beneficiary
41 42 43 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 41 def bank_beneficiary @bank_beneficiary end |
#bank_iban ⇒ Object
Bank iban
35 36 37 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 35 def bank_iban @bank_iban end |
#bank_name ⇒ Object
Bank name
38 39 40 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 38 def bank_name @bank_name end |
#default_payment_account ⇒ Object
Returns the value of attribute default_payment_account.
29 30 31 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 29 def default_payment_account @default_payment_account end |
#details ⇒ Object
Method details rows
32 33 34 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 32 def details @details end |
#ei_payment_method ⇒ Object
EInvoice payment method
44 45 46 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 44 def ei_payment_method @ei_payment_method end |
#id ⇒ Object
Unique identifier
19 20 21 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 19 def id @id end |
#is_default ⇒ Object
Determines if this is the default payment method.
27 28 29 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 27 def is_default @is_default end |
#name ⇒ Object
Name of the payment method
22 23 24 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 22 def name @name end |
#type ⇒ Object
Returns the value of attribute type.
24 25 26 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 24 def type @type end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 63 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 47 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'type' => :'type', :'is_default' => :'is_default', :'default_payment_account' => :'default_payment_account', :'details' => :'details', :'bank_iban' => :'bank_iban', :'bank_name' => :'bank_name', :'bank_beneficiary' => :'bank_beneficiary', :'ei_payment_method' => :'ei_payment_method' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 220 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 88 89 90 91 92 93 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 84 def self.openapi_nullable Set.new([ :'id', :'default_payment_account', :'details', :'bank_iban', :'bank_name', :'bank_beneficiary', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 68 def self.openapi_types { :'id' => :'Integer', :'name' => :'String', :'type' => :'PaymentMethodType', :'is_default' => :'Boolean', :'default_payment_account' => :'PaymentAccount', :'details' => :'Array<PaymentMethodDetails>', :'bank_iban' => :'String', :'bank_name' => :'String', :'bank_beneficiary' => :'String', :'ei_payment_method' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 190 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && type == o.type && is_default == o.is_default && default_payment_account == o.default_payment_account && details == o.details && bank_iban == o.bank_iban && bank_name == o.bank_name && bank_beneficiary == o.bank_beneficiary && ei_payment_method == o.ei_payment_method end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 250 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = FattureInCloud_Ruby_Sdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 321 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 227 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
207 208 209 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 207 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 213 def hash [id, name, type, is_default, default_payment_account, details, bank_iban, bank_name, bank_beneficiary, ei_payment_method].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 157 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if !@details.nil? && @details.length > 5 invalid_properties.push('invalid value for "details", number of items must be less than or equal to 5.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
297 298 299 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 297 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
291 292 293 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 291 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
172 173 174 175 176 |
# File 'lib/fattureincloud_ruby_sdk/models/payment_method.rb', line 172 def valid? return false if @name.nil? return false if !@details.nil? && @details.length > 5 true end |