Class: FattureInCloud_Ruby_Sdk::PermissionsFicIssuedDocumentsDetailed

Inherits:
Object
  • Object
show all
Defined in:
lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PermissionsFicIssuedDocumentsDetailed

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FattureInCloud_Ruby_Sdk::PermissionsFicIssuedDocumentsDetailed` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FattureInCloud_Ruby_Sdk::PermissionsFicIssuedDocumentsDetailed`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'quotes')
    self.quotes = attributes[:'quotes']
  end

  if attributes.key?(:'proformas')
    self.proformas = attributes[:'proformas']
  end

  if attributes.key?(:'invoices')
    self.invoices = attributes[:'invoices']
  end

  if attributes.key?(:'receipts')
    self.receipts = attributes[:'receipts']
  end

  if attributes.key?(:'delivery_notes')
    self.delivery_notes = attributes[:'delivery_notes']
  end

  if attributes.key?(:'credit_notes')
    self.credit_notes = attributes[:'credit_notes']
  end

  if attributes.key?(:'orders')
    self.orders = attributes[:'orders']
  end

  if attributes.key?(:'work_reports')
    self.work_reports = attributes[:'work_reports']
  end

  if attributes.key?(:'supplier_orders')
    self.supplier_orders = attributes[:'supplier_orders']
  end

  if attributes.key?(:'self_invoices')
    self.self_invoices = attributes[:'self_invoices']
  end
end

Instance Attribute Details

#credit_notesObject

Returns the value of attribute credit_notes.



28
29
30
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 28

def credit_notes
  @credit_notes
end

#delivery_notesObject

Returns the value of attribute delivery_notes.



26
27
28
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 26

def delivery_notes
  @delivery_notes
end

#invoicesObject

Returns the value of attribute invoices.



22
23
24
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 22

def invoices
  @invoices
end

#ordersObject

Returns the value of attribute orders.



30
31
32
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 30

def orders
  @orders
end

#proformasObject

Returns the value of attribute proformas.



20
21
22
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 20

def proformas
  @proformas
end

#quotesObject

Returns the value of attribute quotes.



18
19
20
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 18

def quotes
  @quotes
end

#receiptsObject

Returns the value of attribute receipts.



24
25
26
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 24

def receipts
  @receipts
end

#self_invoicesObject

Returns the value of attribute self_invoices.



36
37
38
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 36

def self_invoices
  @self_invoices
end

#supplier_ordersObject

Returns the value of attribute supplier_orders.



34
35
36
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 34

def supplier_orders
  @supplier_orders
end

#work_reportsObject

Returns the value of attribute work_reports.



32
33
34
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 32

def work_reports
  @work_reports
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 236

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  when :Hash
    value
  else # model
    # models (e.g. Pet) or oneOf
    klass = FattureInCloud_Ruby_Sdk.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 61

def self.attribute_map
  {
    :'quotes' => :'quotes',
    :'proformas' => :'proformas',
    :'invoices' => :'invoices',
    :'receipts' => :'receipts',
    :'delivery_notes' => :'delivery_notes',
    :'credit_notes' => :'credit_notes',
    :'orders' => :'orders',
    :'work_reports' => :'work_reports',
    :'supplier_orders' => :'supplier_orders',
    :'self_invoices' => :'self_invoices'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 212

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 87

def self.openapi_types
  {
    :'quotes' => :'PermissionLevel',
    :'proformas' => :'PermissionLevel',
    :'invoices' => :'PermissionLevel',
    :'receipts' => :'PermissionLevel',
    :'delivery_notes' => :'PermissionLevel',
    :'credit_notes' => :'PermissionLevel',
    :'orders' => :'PermissionLevel',
    :'work_reports' => :'PermissionLevel',
    :'supplier_orders' => :'PermissionLevel',
    :'self_invoices' => :'PermissionLevel'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 182

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      quotes == o.quotes &&
      proformas == o.proformas &&
      invoices == o.invoices &&
      receipts == o.receipts &&
      delivery_notes == o.delivery_notes &&
      credit_notes == o.credit_notes &&
      orders == o.orders &&
      work_reports == o.work_reports &&
      supplier_orders == o.supplier_orders &&
      self_invoices == o.self_invoices
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 309

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


199
200
201
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 199

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



205
206
207
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 205

def hash
  [quotes, proformas, invoices, receipts, delivery_notes, credit_notes, orders, work_reports, supplier_orders, self_invoices].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



285
286
287
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 285

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 291

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



279
280
281
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 279

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



175
176
177
178
# File 'lib/fattureincloud_ruby_sdk/models/permissions_fic_issued_documents_detailed.rb', line 175

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end