Class: FattureInCloud_Ruby_Sdk::Receipt

Inherits:
Object
  • Object
show all
Defined in:
lib/fattureincloud_ruby_sdk/models/receipt.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Receipt

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FattureInCloud_Ruby_Sdk::Receipt` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FattureInCloud_Ruby_Sdk::Receipt`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  end

  if attributes.key?(:'numeration')
    self.numeration = attributes[:'numeration']
  end

  if attributes.key?(:'amount_net')
    self.amount_net = attributes[:'amount_net']
  end

  if attributes.key?(:'amount_vat')
    self.amount_vat = attributes[:'amount_vat']
  end

  if attributes.key?(:'amount_gross')
    self.amount_gross = attributes[:'amount_gross']
  end

  if attributes.key?(:'use_gross_prices')
    self.use_gross_prices = attributes[:'use_gross_prices']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'rc_center')
    self.rc_center = attributes[:'rc_center']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'payment_account')
    self. = attributes[:'payment_account']
  end

  if attributes.key?(:'items_list')
    if (value = attributes[:'items_list']).is_a?(Array)
      self.items_list = value
    end
  end
end

Instance Attribute Details

#amount_grossObject

Total gross amount.



38
39
40
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 38

def amount_gross
  @amount_gross
end

#amount_netObject

Total net amount.



32
33
34
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 32

def amount_net
  @amount_net
end

#amount_vatObject

Total vat amount.



35
36
37
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 35

def amount_vat
  @amount_vat
end

#created_atObject

Returns the value of attribute created_at.



50
51
52
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 50

def created_at
  @created_at
end

#dateObject

Receipt date.



23
24
25
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 23

def date
  @date
end

#descriptionObject

Receipt description.



45
46
47
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 45

def description
  @description
end

#idObject

Receipt unique identifier.



20
21
22
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 20

def id
  @id
end

#items_listObject

Returns the value of attribute items_list.



56
57
58
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 56

def items_list
  @items_list
end

#numberObject

Receipt number.



26
27
28
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 26

def number
  @number
end

#numerationObject

If it’s null or empty string use the default numeration.



29
30
31
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 29

def numeration
  @numeration
end

#payment_accountObject

Returns the value of attribute payment_account.



54
55
56
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 54

def 
  
end

#rc_centerObject

Revenue center.



48
49
50
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 48

def rc_center
  @rc_center
end

#typeObject

Returns the value of attribute type.



42
43
44
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 42

def type
  @type
end

#updated_atObject

Returns the value of attribute updated_at.



52
53
54
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 52

def updated_at
  @updated_at
end

#use_gross_pricesObject

Returns the value of attribute use_gross_prices.



40
41
42
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 40

def use_gross_prices
  @use_gross_prices
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



102
103
104
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 102

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 81

def self.attribute_map
  {
    :'id' => :'id',
    :'date' => :'date',
    :'number' => :'number',
    :'numeration' => :'numeration',
    :'amount_net' => :'amount_net',
    :'amount_vat' => :'amount_vat',
    :'amount_gross' => :'amount_gross',
    :'use_gross_prices' => :'use_gross_prices',
    :'type' => :'type',
    :'description' => :'description',
    :'rc_center' => :'rc_center',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'payment_account' => :'payment_account',
    :'items_list' => :'items_list'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 275

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 128

def self.openapi_nullable
  Set.new([
    :'id',
    :'date',
    :'number',
    :'numeration',
    :'amount_net',
    :'amount_vat',
    :'amount_gross',
    :'use_gross_prices',
    :'description',
    :'rc_center',
    :'created_at',
    :'updated_at',
    :'payment_account',
    :'items_list'
  ])
end

.openapi_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 107

def self.openapi_types
  {
    :'id' => :'Integer',
    :'date' => :'Date',
    :'number' => :'Float',
    :'numeration' => :'String',
    :'amount_net' => :'Float',
    :'amount_vat' => :'Float',
    :'amount_gross' => :'Float',
    :'use_gross_prices' => :'Boolean',
    :'type' => :'ReceiptType',
    :'description' => :'String',
    :'rc_center' => :'String',
    :'created_at' => :'String',
    :'updated_at' => :'String',
    :'payment_account' => :'PaymentAccount',
    :'items_list' => :'Array<ReceiptItemsListItem>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 240

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      date == o.date &&
      number == o.number &&
      numeration == o.numeration &&
      amount_net == o.amount_net &&
      amount_vat == o.amount_vat &&
      amount_gross == o.amount_gross &&
      use_gross_prices == o.use_gross_prices &&
      type == o.type &&
      description == o.description &&
      rc_center == o.rc_center &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
       == o. &&
      items_list == o.items_list
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 306

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  when :Hash
    value
  else # model
    # models (e.g. Pet) or oneOf
    klass = FattureInCloud_Ruby_Sdk.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 379

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 282

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 268

def hash
  [id, date, number, numeration, amount_net, amount_vat, amount_gross, use_gross_prices, type, description, rc_center, created_at, updated_at, , items_list].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



227
228
229
230
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 227

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



355
356
357
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 355

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 361

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



349
350
351
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 349

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



234
235
236
# File 'lib/fattureincloud_ruby_sdk/models/receipt.rb', line 234

def valid?
  true
end