Class: FattureInCloud_Ruby_Sdk::Entity
- Inherits:
-
Object
- Object
- FattureInCloud_Ruby_Sdk::Entity
- Defined in:
- lib/fattureincloud_ruby_sdk/models/entity.rb
Instance Attribute Summary collapse
-
#address_city ⇒ Object
City.
-
#address_extra ⇒ Object
Address extra info.
-
#address_postal_code ⇒ Object
Postal code.
-
#address_province ⇒ Object
Province.
-
#address_street ⇒ Object
Street address.
-
#bank_iban ⇒ Object
- Only for client
-
Iban.
-
#bank_name ⇒ Object
- Only for client
-
Bank name.
-
#bank_swift_code ⇒ Object
- Only for client
-
Bank swift code.
-
#certified_email ⇒ Object
Certified email.
-
#code ⇒ Object
Code.
-
#contact_person ⇒ Object
Returns the value of attribute contact_person.
-
#country ⇒ Object
Country.
-
#country_iso ⇒ Object
Country Iso.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#default_payment_method ⇒ Object
Returns the value of attribute default_payment_method.
-
#default_payment_terms ⇒ Object
- Only for client
-
Default payment terms.
-
#default_payment_terms_type ⇒ Object
Returns the value of attribute default_payment_terms_type.
-
#default_vat ⇒ Object
Returns the value of attribute default_vat.
-
#e_invoice ⇒ Object
- Only for client
-
Use e-invoices.
-
#ei_code ⇒ Object
- Only for client
-
E-invoices code.
-
#email ⇒ Object
Email.
-
#fax ⇒ Object
Fax.
-
#first_name ⇒ Object
First name.
-
#has_intent_declaration ⇒ Object
- Only for client
-
Has intent declaration.
-
#id ⇒ Object
Unique identifier.
-
#intent_declaration_protocol_date ⇒ Object
- Only for client
-
Intent declaration protocol date.
-
#intent_declaration_protocol_number ⇒ Object
- Only for client
-
Intent declaration protocol number.
-
#last_name ⇒ Object
Last name.
-
#name ⇒ Object
Name.
-
#notes ⇒ Object
Extra notes.
-
#phone ⇒ Object
Phone.
-
#shipping_address ⇒ Object
- Only for client
-
Shipping address.
-
#tax_code ⇒ Object
Tax code.
-
#type ⇒ Object
Returns the value of attribute type.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#vat_number ⇒ Object
Vat number.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Entity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Entity
Initializes the object
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 251 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FattureInCloud_Ruby_Sdk::Entity` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FattureInCloud_Ruby_Sdk::Entity`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'code') self.code = attributes[:'code'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'contact_person') self.contact_person = attributes[:'contact_person'] end if attributes.key?(:'vat_number') self.vat_number = attributes[:'vat_number'] end if attributes.key?(:'tax_code') self.tax_code = attributes[:'tax_code'] end if attributes.key?(:'address_street') self.address_street = attributes[:'address_street'] end if attributes.key?(:'address_postal_code') self.address_postal_code = attributes[:'address_postal_code'] end if attributes.key?(:'address_city') self.address_city = attributes[:'address_city'] end if attributes.key?(:'address_province') self.address_province = attributes[:'address_province'] end if attributes.key?(:'address_extra') self.address_extra = attributes[:'address_extra'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'country_iso') self.country_iso = attributes[:'country_iso'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'certified_email') self.certified_email = attributes[:'certified_email'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'fax') self.fax = attributes[:'fax'] end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end if attributes.key?(:'default_vat') self.default_vat = attributes[:'default_vat'] end if attributes.key?(:'default_payment_terms') self.default_payment_terms = attributes[:'default_payment_terms'] end if attributes.key?(:'default_payment_terms_type') self.default_payment_terms_type = attributes[:'default_payment_terms_type'] else self.default_payment_terms_type = 'standard' end if attributes.key?(:'default_payment_method') self.default_payment_method = attributes[:'default_payment_method'] end if attributes.key?(:'bank_name') self.bank_name = attributes[:'bank_name'] end if attributes.key?(:'bank_iban') self.bank_iban = attributes[:'bank_iban'] end if attributes.key?(:'bank_swift_code') self.bank_swift_code = attributes[:'bank_swift_code'] end if attributes.key?(:'shipping_address') self.shipping_address = attributes[:'shipping_address'] end if attributes.key?(:'e_invoice') self.e_invoice = attributes[:'e_invoice'] end if attributes.key?(:'ei_code') self.ei_code = attributes[:'ei_code'] end if attributes.key?(:'has_intent_declaration') self.has_intent_declaration = attributes[:'has_intent_declaration'] end if attributes.key?(:'intent_declaration_protocol_number') self.intent_declaration_protocol_number = attributes[:'intent_declaration_protocol_number'] end if attributes.key?(:'intent_declaration_protocol_date') self.intent_declaration_protocol_date = attributes[:'intent_declaration_protocol_date'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#address_city ⇒ Object
City.
51 52 53 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 51 def address_city @address_city end |
#address_extra ⇒ Object
Address extra info.
57 58 59 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 57 def address_extra @address_extra end |
#address_postal_code ⇒ Object
Postal code.
48 49 50 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 48 def address_postal_code @address_postal_code end |
#address_province ⇒ Object
Province.
54 55 56 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 54 def address_province @address_province end |
#address_street ⇒ Object
Street address.
45 46 47 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 45 def address_street @address_street end |
#bank_iban ⇒ Object
- Only for client
-
Iban.
93 94 95 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 93 def bank_iban @bank_iban end |
#bank_name ⇒ Object
- Only for client
-
Bank name.
90 91 92 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 90 def bank_name @bank_name end |
#bank_swift_code ⇒ Object
- Only for client
-
Bank swift code.
96 97 98 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 96 def bank_swift_code @bank_swift_code end |
#certified_email ⇒ Object
Certified email.
69 70 71 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 69 def certified_email @certified_email end |
#code ⇒ Object
Code.
23 24 25 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 23 def code @code end |
#contact_person ⇒ Object
Returns the value of attribute contact_person.
36 37 38 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 36 def contact_person @contact_person end |
#country ⇒ Object
Country
60 61 62 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 60 def country @country end |
#country_iso ⇒ Object
Country Iso
63 64 65 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 63 def country_iso @country_iso end |
#created_at ⇒ Object
Returns the value of attribute created_at.
116 117 118 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 116 def created_at @created_at end |
#default_payment_method ⇒ Object
Returns the value of attribute default_payment_method.
87 88 89 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 87 def default_payment_method @default_payment_method end |
#default_payment_terms ⇒ Object
- Only for client
-
Default payment terms.
83 84 85 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 83 def default_payment_terms @default_payment_terms end |
#default_payment_terms_type ⇒ Object
Returns the value of attribute default_payment_terms_type.
85 86 87 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 85 def default_payment_terms_type @default_payment_terms_type end |
#default_vat ⇒ Object
Returns the value of attribute default_vat.
80 81 82 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 80 def default_vat @default_vat end |
#e_invoice ⇒ Object
- Only for client
-
Use e-invoices.
102 103 104 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 102 def e_invoice @e_invoice end |
#ei_code ⇒ Object
- Only for client
-
E-invoices code.
105 106 107 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 105 def ei_code @ei_code end |
#email ⇒ Object
Email.
66 67 68 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 66 def email @email end |
#fax ⇒ Object
Fax.
75 76 77 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 75 def fax @fax end |
#first_name ⇒ Object
First name.
31 32 33 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 31 def first_name @first_name end |
#has_intent_declaration ⇒ Object
- Only for client
-
Has intent declaration.
108 109 110 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 108 def has_intent_declaration @has_intent_declaration end |
#id ⇒ Object
Unique identifier
20 21 22 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 20 def id @id end |
#intent_declaration_protocol_date ⇒ Object
- Only for client
-
Intent declaration protocol date.
114 115 116 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 114 def intent_declaration_protocol_date @intent_declaration_protocol_date end |
#intent_declaration_protocol_number ⇒ Object
- Only for client
-
Intent declaration protocol number.
111 112 113 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 111 def intent_declaration_protocol_number @intent_declaration_protocol_number end |
#last_name ⇒ Object
Last name.
34 35 36 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 34 def last_name @last_name end |
#name ⇒ Object
Name
26 27 28 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 26 def name @name end |
#notes ⇒ Object
Extra notes.
78 79 80 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 78 def notes @notes end |
#phone ⇒ Object
Phone.
72 73 74 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 72 def phone @phone end |
#shipping_address ⇒ Object
- Only for client
-
Shipping address.
99 100 101 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 99 def shipping_address @shipping_address end |
#tax_code ⇒ Object
Tax code.
42 43 44 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 42 def tax_code @tax_code end |
#type ⇒ Object
Returns the value of attribute type.
28 29 30 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 28 def type @type end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
118 119 120 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 118 def updated_at @updated_at end |
#vat_number ⇒ Object
Vat number
39 40 41 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 39 def vat_number @vat_number end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
163 164 165 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 163 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 121 def self.attribute_map { :'id' => :'id', :'code' => :'code', :'name' => :'name', :'type' => :'type', :'first_name' => :'first_name', :'last_name' => :'last_name', :'contact_person' => :'contact_person', :'vat_number' => :'vat_number', :'tax_code' => :'tax_code', :'address_street' => :'address_street', :'address_postal_code' => :'address_postal_code', :'address_city' => :'address_city', :'address_province' => :'address_province', :'address_extra' => :'address_extra', :'country' => :'country', :'country_iso' => :'country_iso', :'email' => :'email', :'certified_email' => :'certified_email', :'phone' => :'phone', :'fax' => :'fax', :'notes' => :'notes', :'default_vat' => :'default_vat', :'default_payment_terms' => :'default_payment_terms', :'default_payment_terms_type' => :'default_payment_terms_type', :'default_payment_method' => :'default_payment_method', :'bank_name' => :'bank_name', :'bank_iban' => :'bank_iban', :'bank_swift_code' => :'bank_swift_code', :'shipping_address' => :'shipping_address', :'e_invoice' => :'e_invoice', :'ei_code' => :'ei_code', :'has_intent_declaration' => :'has_intent_declaration', :'intent_declaration_protocol_number' => :'intent_declaration_protocol_number', :'intent_declaration_protocol_date' => :'intent_declaration_protocol_date', :'created_at' => :'created_at', :'updated_at' => :'updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
482 483 484 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 482 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 210 def self.openapi_nullable Set.new([ :'id', :'code', :'name', :'type', :'first_name', :'last_name', :'contact_person', :'vat_number', :'tax_code', :'address_street', :'address_postal_code', :'address_city', :'address_province', :'address_extra', :'country', :'country_iso', :'email', :'certified_email', :'phone', :'fax', :'notes', :'default_vat', :'default_payment_terms', :'bank_name', :'bank_iban', :'bank_swift_code', :'shipping_address', :'e_invoice', :'ei_code', :'has_intent_declaration', :'intent_declaration_protocol_number', :'intent_declaration_protocol_date', :'created_at', :'updated_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 168 def self.openapi_types { :'id' => :'Integer', :'code' => :'String', :'name' => :'String', :'type' => :'EntityType', :'first_name' => :'String', :'last_name' => :'String', :'contact_person' => :'String', :'vat_number' => :'String', :'tax_code' => :'String', :'address_street' => :'String', :'address_postal_code' => :'String', :'address_city' => :'String', :'address_province' => :'String', :'address_extra' => :'String', :'country' => :'String', :'country_iso' => :'String', :'email' => :'String', :'certified_email' => :'String', :'phone' => :'String', :'fax' => :'String', :'notes' => :'String', :'default_vat' => :'VatType', :'default_payment_terms' => :'Integer', :'default_payment_terms_type' => :'PaymentTermsType', :'default_payment_method' => :'PaymentMethod', :'bank_name' => :'String', :'bank_iban' => :'String', :'bank_swift_code' => :'String', :'shipping_address' => :'String', :'e_invoice' => :'Boolean', :'ei_code' => :'String', :'has_intent_declaration' => :'Boolean', :'intent_declaration_protocol_number' => :'String', :'intent_declaration_protocol_date' => :'Date', :'created_at' => :'String', :'updated_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 426 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && code == o.code && name == o.name && type == o.type && first_name == o.first_name && last_name == o.last_name && contact_person == o.contact_person && vat_number == o.vat_number && tax_code == o.tax_code && address_street == o.address_street && address_postal_code == o.address_postal_code && address_city == o.address_city && address_province == o.address_province && address_extra == o.address_extra && country == o.country && country_iso == o.country_iso && email == o.email && certified_email == o.certified_email && phone == o.phone && fax == o.fax && notes == o.notes && default_vat == o.default_vat && default_payment_terms == o.default_payment_terms && default_payment_terms_type == o.default_payment_terms_type && default_payment_method == o.default_payment_method && bank_name == o.bank_name && bank_iban == o.bank_iban && bank_swift_code == o.bank_swift_code && shipping_address == o.shipping_address && e_invoice == o.e_invoice && ei_code == o.ei_code && has_intent_declaration == o.has_intent_declaration && intent_declaration_protocol_number == o.intent_declaration_protocol_number && intent_declaration_protocol_date == o.intent_declaration_protocol_date && created_at == o.created_at && updated_at == o.updated_at end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 513 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end when :Hash value else # model # models (e.g. Pet) or oneOf klass = FattureInCloud_Ruby_Sdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 586 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 489 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
469 470 471 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 469 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
475 476 477 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 475 def hash [id, code, name, type, first_name, last_name, contact_person, vat_number, tax_code, address_street, address_postal_code, address_city, address_province, address_extra, country, country_iso, email, certified_email, phone, fax, notes, default_vat, default_payment_terms, default_payment_terms_type, default_payment_method, bank_name, bank_iban, bank_swift_code, shipping_address, e_invoice, ei_code, has_intent_declaration, intent_declaration_protocol_number, intent_declaration_protocol_date, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
413 414 415 416 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 413 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
562 563 564 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 562 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
568 569 570 571 572 573 574 575 576 577 578 579 580 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 568 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
556 557 558 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 556 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
420 421 422 |
# File 'lib/fattureincloud_ruby_sdk/models/entity.rb', line 420 def valid? true end |