Class: FattureInCloud_Ruby_Sdk::IssuedDocumentExtraData
- Inherits:
-
Object
- Object
- FattureInCloud_Ruby_Sdk::IssuedDocumentExtraData
- Defined in:
- lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb
Overview
Issued document extra data [TS fields follow the technical specifications provided by "Sistema Tessera Sanitaria"]
Instance Attribute Summary collapse
-
#imported_by ⇒ Object
Issued document imported by software.
-
#multifatture_sent ⇒ Object
Returns the value of attribute multifatture_sent.
-
#show_sofort_button ⇒ Object
Returns the value of attribute show_sofort_button.
-
#ts_communication ⇒ Object
Send issued document to "Sistema Tessera Sanitaria".
-
#ts_file_id ⇒ Object
Issued document ts file id.
-
#ts_flag_tipo_spesa ⇒ Object
Issued document ts "tipo spesa" [TK, FC, FV, SV,SP, AD, AS, ECG, SR].
-
#ts_full_amount ⇒ Object
Issued document ts total amount.
-
#ts_opposizione ⇒ Object
Issued document ts "opposizione".
-
#ts_pagamento_tracciato ⇒ Object
Issued document ts traced payment.
-
#ts_sent_date ⇒ Object
Issued document ts sent date.
-
#ts_status ⇒ Object
Issued document ts status.
-
#ts_tipo_spesa ⇒ Object
Can be [ ‘TK’, ‘FC’, ‘FV’, ‘SV’, ‘SP’, ‘AD’, ‘AS’, ‘SR’, ‘CT’, ‘PI’, ‘IC’, ‘AA’ ].
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IssuedDocumentExtraData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IssuedDocumentExtraData
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FattureInCloud_Ruby_Sdk::IssuedDocumentExtraData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FattureInCloud_Ruby_Sdk::IssuedDocumentExtraData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'show_sofort_button') self. = attributes[:'show_sofort_button'] end if attributes.key?(:'multifatture_sent') self.multifatture_sent = attributes[:'multifatture_sent'] end if attributes.key?(:'ts_communication') self.ts_communication = attributes[:'ts_communication'] end if attributes.key?(:'ts_flag_tipo_spesa') self.ts_flag_tipo_spesa = attributes[:'ts_flag_tipo_spesa'] end if attributes.key?(:'ts_pagamento_tracciato') self.ts_pagamento_tracciato = attributes[:'ts_pagamento_tracciato'] end if attributes.key?(:'ts_tipo_spesa') self.ts_tipo_spesa = attributes[:'ts_tipo_spesa'] end if attributes.key?(:'ts_opposizione') self.ts_opposizione = attributes[:'ts_opposizione'] end if attributes.key?(:'ts_status') self.ts_status = attributes[:'ts_status'] end if attributes.key?(:'ts_file_id') self.ts_file_id = attributes[:'ts_file_id'] end if attributes.key?(:'ts_sent_date') self.ts_sent_date = attributes[:'ts_sent_date'] end if attributes.key?(:'ts_full_amount') self.ts_full_amount = attributes[:'ts_full_amount'] end if attributes.key?(:'imported_by') self.imported_by = attributes[:'imported_by'] end end |
Instance Attribute Details
#imported_by ⇒ Object
Issued document imported by software
51 52 53 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 51 def imported_by @imported_by end |
#multifatture_sent ⇒ Object
Returns the value of attribute multifatture_sent.
21 22 23 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 21 def multifatture_sent @multifatture_sent end |
#show_sofort_button ⇒ Object
Returns the value of attribute show_sofort_button.
19 20 21 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 19 def @show_sofort_button end |
#ts_communication ⇒ Object
Send issued document to "Sistema Tessera Sanitaria"
24 25 26 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 24 def ts_communication @ts_communication end |
#ts_file_id ⇒ Object
Issued document ts file id
42 43 44 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 42 def ts_file_id @ts_file_id end |
#ts_flag_tipo_spesa ⇒ Object
Issued document ts "tipo spesa" [TK, FC, FV, SV,SP, AD, AS, ECG, SR]
27 28 29 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 27 def ts_flag_tipo_spesa @ts_flag_tipo_spesa end |
#ts_full_amount ⇒ Object
Issued document ts total amount
48 49 50 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 48 def ts_full_amount @ts_full_amount end |
#ts_opposizione ⇒ Object
Issued document ts "opposizione"
36 37 38 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 36 def ts_opposizione @ts_opposizione end |
#ts_pagamento_tracciato ⇒ Object
Issued document ts traced payment
30 31 32 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 30 def ts_pagamento_tracciato @ts_pagamento_tracciato end |
#ts_sent_date ⇒ Object
Issued document ts sent date
45 46 47 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 45 def ts_sent_date @ts_sent_date end |
#ts_status ⇒ Object
Issued document ts status
39 40 41 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 39 def ts_status @ts_status end |
#ts_tipo_spesa ⇒ Object
Can be [ ‘TK’, ‘FC’, ‘FV’, ‘SV’, ‘SP’, ‘AD’, ‘AS’, ‘SR’, ‘CT’, ‘PI’, ‘IC’, ‘AA’ ]. Refer to the technical specifications to learn more.
33 34 35 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 33 def ts_tipo_spesa @ts_tipo_spesa end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 72 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 54 def self.attribute_map { :'show_sofort_button' => :'show_sofort_button', :'multifatture_sent' => :'multifatture_sent', :'ts_communication' => :'ts_communication', :'ts_flag_tipo_spesa' => :'ts_flag_tipo_spesa', :'ts_pagamento_tracciato' => :'ts_pagamento_tracciato', :'ts_tipo_spesa' => :'ts_tipo_spesa', :'ts_opposizione' => :'ts_opposizione', :'ts_status' => :'ts_status', :'ts_file_id' => :'ts_file_id', :'ts_sent_date' => :'ts_sent_date', :'ts_full_amount' => :'ts_full_amount', :'imported_by' => :'imported_by' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 223 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 95 def self.openapi_nullable Set.new([ :'show_sofort_button', :'multifatture_sent', :'ts_communication', :'ts_flag_tipo_spesa', :'ts_pagamento_tracciato', :'ts_tipo_spesa', :'ts_opposizione', :'ts_status', :'ts_file_id', :'ts_sent_date', :'ts_full_amount', :'imported_by' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 77 def self.openapi_types { :'show_sofort_button' => :'Boolean', :'multifatture_sent' => :'Integer', :'ts_communication' => :'Boolean', :'ts_flag_tipo_spesa' => :'Float', :'ts_pagamento_tracciato' => :'Boolean', :'ts_tipo_spesa' => :'String', :'ts_opposizione' => :'Boolean', :'ts_status' => :'Integer', :'ts_file_id' => :'String', :'ts_sent_date' => :'Date', :'ts_full_amount' => :'Boolean', :'imported_by' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && multifatture_sent == o.multifatture_sent && ts_communication == o.ts_communication && ts_flag_tipo_spesa == o.ts_flag_tipo_spesa && ts_pagamento_tracciato == o.ts_pagamento_tracciato && ts_tipo_spesa == o.ts_tipo_spesa && ts_opposizione == o.ts_opposizione && ts_status == o.ts_status && ts_file_id == o.ts_file_id && ts_sent_date == o.ts_sent_date && ts_full_amount == o.ts_full_amount && imported_by == o.imported_by end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 254 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end when :Hash value else # model # models (e.g. Pet) or oneOf klass = FattureInCloud_Ruby_Sdk.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 327 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 230 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 216 def hash [, multifatture_sent, ts_communication, ts_flag_tipo_spesa, ts_pagamento_tracciato, ts_tipo_spesa, ts_opposizione, ts_status, ts_file_id, ts_sent_date, ts_full_amount, imported_by].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
178 179 180 181 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 178 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
303 304 305 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 303 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 309 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
297 298 299 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 297 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
185 186 187 |
# File 'lib/fattureincloud_ruby_sdk/models/issued_document_extra_data.rb', line 185 def valid? true end |