Class: FattureInCloud_Ruby_Sdk::PendingReceivedDocument
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FattureInCloud_Ruby_Sdk::PendingReceivedDocument
- Defined in:
- lib/fattureincloud_ruby_sdk/models/pending_received_document.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount_gross ⇒ Object
- Read Only
-
Pending received document total gross amount.
-
#amount_net ⇒ Object
Pending received document total net amount.
-
#amount_vat ⇒ Object
Pending received document total vat amount.
-
#attachment_url ⇒ Object
- Temporary
- Read Only
-
Pending received document url of the attached file.
-
#category ⇒ Object
Pending received document category.
-
#cost_center ⇒ Object
Pending received document cost center.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#date ⇒ Object
Pending received document date.
-
#document_type ⇒ Object
Returns the value of attribute document_type.
-
#emssion_date ⇒ Object
Pending received document emission date.
-
#extracted_data ⇒ Object
Returns the value of attribute extracted_data.
-
#filename ⇒ Object
Pending received document filename.
-
#id ⇒ Object
Pending received document id.
-
#import_error ⇒ Object
Pending received document import error.
-
#other_attachments ⇒ Object
Pending received document other attachments.
-
#payments_list ⇒ Object
Returns the value of attribute payments_list.
-
#subject ⇒ Object
Pending received document subject.
-
#supplier_name ⇒ Object
Pending received document supplier name.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PendingReceivedDocument
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PendingReceivedDocument
Initializes the object
176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 176 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FattureInCloud_Ruby_Sdk::PendingReceivedDocument` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FattureInCloud_Ruby_Sdk::PendingReceivedDocument`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'filename') self.filename = attributes[:'filename'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = 'agyo' end if attributes.key?(:'attachment_url') self. = attributes[:'attachment_url'] end if attributes.key?(:'amount_gross') self.amount_gross = attributes[:'amount_gross'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'document_type') self.document_type = attributes[:'document_type'] else self.document_type = 'expense' end if attributes.key?(:'supplier_name') self.supplier_name = attributes[:'supplier_name'] end if attributes.key?(:'cost_center') self.cost_center = attributes[:'cost_center'] end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'other_attachments') if (value = attributes[:'other_attachments']).is_a?(Array) self. = value end end if attributes.key?(:'emssion_date') self.emssion_date = attributes[:'emssion_date'] end if attributes.key?(:'payments_list') if (value = attributes[:'payments_list']).is_a?(Array) self.payments_list = value end end if attributes.key?(:'amount_net') self.amount_net = attributes[:'amount_net'] end if attributes.key?(:'amount_vat') self.amount_vat = attributes[:'amount_vat'] end if attributes.key?(:'import_error') self.import_error = attributes[:'import_error'] end if attributes.key?(:'extracted_data') self.extracted_data = attributes[:'extracted_data'] end end |
Instance Attribute Details
#amount_gross ⇒ Object
- Read Only
-
Pending received document total gross amount
36 37 38 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 36 def amount_gross @amount_gross end |
#amount_net ⇒ Object
Pending received document total net amount
60 61 62 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 60 def amount_net @amount_net end |
#amount_vat ⇒ Object
Pending received document total vat amount
63 64 65 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 63 def amount_vat @amount_vat end |
#attachment_url ⇒ Object
- Temporary
- Read Only
-
Pending received document url of the attached file
33 34 35 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 33 def @attachment_url end |
#category ⇒ Object
Pending received document category
49 50 51 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 49 def category @category end |
#cost_center ⇒ Object
Pending received document cost center
46 47 48 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 46 def cost_center @cost_center end |
#currency ⇒ Object
Returns the value of attribute currency.
38 39 40 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 38 def currency @currency end |
#date ⇒ Object
Pending received document date
22 23 24 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 22 def date @date end |
#document_type ⇒ Object
Returns the value of attribute document_type.
40 41 42 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 40 def document_type @document_type end |
#emssion_date ⇒ Object
Pending received document emission date
55 56 57 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 55 def emssion_date @emssion_date end |
#extracted_data ⇒ Object
Returns the value of attribute extracted_data.
68 69 70 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 68 def extracted_data @extracted_data end |
#filename ⇒ Object
Pending received document filename
28 29 30 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 28 def filename @filename end |
#id ⇒ Object
Pending received document id
19 20 21 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 19 def id @id end |
#import_error ⇒ Object
Pending received document import error
66 67 68 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 66 def import_error @import_error end |
#other_attachments ⇒ Object
Pending received document other attachments
52 53 54 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 52 def @other_attachments end |
#payments_list ⇒ Object
Returns the value of attribute payments_list.
57 58 59 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 57 def payments_list @payments_list end |
#subject ⇒ Object
Pending received document subject
25 26 27 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 25 def subject @subject end |
#supplier_name ⇒ Object
Pending received document supplier name
43 44 45 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 43 def supplier_name @supplier_name end |
#type ⇒ Object
Returns the value of attribute type.
30 31 32 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 30 def type @type end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 355 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end when :Hash value else # model # models (e.g. Pet) or oneOf klass = FattureInCloud_Ruby_Sdk.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
118 119 120 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 118 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
123 124 125 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 123 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 93 def self.attribute_map { :'id' => :'id', :'date' => :'date', :'subject' => :'subject', :'filename' => :'filename', :'type' => :'type', :'attachment_url' => :'attachment_url', :'amount_gross' => :'amount_gross', :'currency' => :'currency', :'document_type' => :'document_type', :'supplier_name' => :'supplier_name', :'cost_center' => :'cost_center', :'category' => :'category', :'other_attachments' => :'other_attachments', :'emssion_date' => :'emssion_date', :'payments_list' => :'payments_list', :'amount_net' => :'amount_net', :'amount_vat' => :'amount_vat', :'import_error' => :'import_error', :'extracted_data' => :'extracted_data' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 331 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 153 def self.openapi_nullable Set.new([ :'id', :'date', :'subject', :'filename', :'attachment_url', :'amount_gross', :'supplier_name', :'cost_center', :'category', :'other_attachments', :'emssion_date', :'payments_list', :'amount_net', :'amount_vat', :'import_error', :'extracted_data' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 128 def self.openapi_types { :'id' => :'Integer', :'date' => :'Date', :'subject' => :'String', :'filename' => :'String', :'type' => :'PendingReceivedDocumentType', :'attachment_url' => :'String', :'amount_gross' => :'Float', :'currency' => :'Currency', :'document_type' => :'ReceivedDocumentType', :'supplier_name' => :'String', :'cost_center' => :'String', :'category' => :'String', :'other_attachments' => :'Array<Attachment>', :'emssion_date' => :'Date', :'payments_list' => :'Array<PendingReceivedDocumentPaymentsListItem>', :'amount_net' => :'Float', :'amount_vat' => :'Float', :'import_error' => :'String', :'extracted_data' => :'PendingReceivedDocumentExtractedData' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 292 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && date == o.date && subject == o.subject && filename == o.filename && type == o.type && == o. && amount_gross == o.amount_gross && currency == o.currency && document_type == o.document_type && supplier_name == o.supplier_name && cost_center == o.cost_center && category == o.category && == o. && emssion_date == o.emssion_date && payments_list == o.payments_list && amount_net == o.amount_net && amount_vat == o.amount_vat && import_error == o.import_error && extracted_data == o.extracted_data end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 428 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
318 319 320 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 318 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
324 325 326 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 324 def hash [id, date, subject, filename, type, , amount_gross, currency, document_type, supplier_name, cost_center, category, , emssion_date, payments_list, amount_net, amount_vat, import_error, extracted_data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
277 278 279 280 281 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 277 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
404 405 406 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 404 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 410 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
398 399 400 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 398 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
285 286 287 288 |
# File 'lib/fattureincloud_ruby_sdk/models/pending_received_document.rb', line 285 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |