Class: FattureInCloud_Ruby_Sdk::SettingsApi
- Inherits:
-
Object
- Object
- FattureInCloud_Ruby_Sdk::SettingsApi
- Defined in:
- lib/fattureincloud_ruby_sdk/api/settings_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_payment_account(company_id, opts = {}) ⇒ CreatePaymentAccountResponse
Create Payment Account Creates a new payment account.
-
#create_payment_account_with_http_info(company_id, opts = {}) ⇒ Array<(CreatePaymentAccountResponse, Integer, Hash)>
Create Payment Account Creates a new payment account.
-
#create_payment_method(company_id, opts = {}) ⇒ CreatePaymentMethodResponse
Create Payment Method Creates a new payment method.
-
#create_payment_method_with_http_info(company_id, opts = {}) ⇒ Array<(CreatePaymentMethodResponse, Integer, Hash)>
Create Payment Method Creates a new payment method.
-
#create_vat_type(company_id, opts = {}) ⇒ CreateVatTypeResponse
Create Vat Type Creates a vat type.
-
#create_vat_type_with_http_info(company_id, opts = {}) ⇒ Array<(CreateVatTypeResponse, Integer, Hash)>
Create Vat Type Creates a vat type.
-
#delete_payment_account(company_id, payment_account_id, opts = {}) ⇒ nil
Delete Payment Account Deletes the specified payment account.
-
#delete_payment_account_with_http_info(company_id, payment_account_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Payment Account Deletes the specified payment account.
-
#delete_payment_method(company_id, payment_method_id, opts = {}) ⇒ nil
Delete Payment Method Deletes the specified payment method.
-
#delete_payment_method_with_http_info(company_id, payment_method_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Payment Method Deletes the specified payment method.
-
#delete_vat_type(company_id, vat_type_id, opts = {}) ⇒ nil
Delete Vat Type Deletes the specified vat type.
-
#delete_vat_type_with_http_info(company_id, vat_type_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Vat Type Deletes the specified vat type.
-
#get_payment_account(company_id, payment_account_id, opts = {}) ⇒ GetPaymentAccountResponse
Get Payment Account Gets the specified payment account.
-
#get_payment_account_with_http_info(company_id, payment_account_id, opts = {}) ⇒ Array<(GetPaymentAccountResponse, Integer, Hash)>
Get Payment Account Gets the specified payment account.
-
#get_payment_method(company_id, payment_method_id, opts = {}) ⇒ GetPaymentMethodResponse
Get Payment Method Gets the specified payment method.
-
#get_payment_method_with_http_info(company_id, payment_method_id, opts = {}) ⇒ Array<(GetPaymentMethodResponse, Integer, Hash)>
Get Payment Method Gets the specified payment method.
-
#get_tax_profile(company_id, opts = {}) ⇒ GetTaxProfileResponse
Get Tax Profile Gets the Tax Profile.
-
#get_tax_profile_with_http_info(company_id, opts = {}) ⇒ Array<(GetTaxProfileResponse, Integer, Hash)>
Get Tax Profile Gets the Tax Profile.
-
#get_template(company_id, template_id, opts = {}) ⇒ GetTemplatesResponse
Get Template Gets a specified template.
-
#get_template_with_http_info(company_id, template_id, opts = {}) ⇒ Array<(GetTemplatesResponse, Integer, Hash)>
Get Template Gets a specified template.
-
#get_vat_type(company_id, vat_type_id, opts = {}) ⇒ GetVatTypeResponse
Get Vat Type Gets the specified vat type.
-
#get_vat_type_with_http_info(company_id, vat_type_id, opts = {}) ⇒ Array<(GetVatTypeResponse, Integer, Hash)>
Get Vat Type Gets the specified vat type.
-
#initialize(api_client = ApiClient.default) ⇒ SettingsApi
constructor
A new instance of SettingsApi.
-
#list_default_templates(company_id, opts = {}) ⇒ ListTemplatesResponse
List Default Templates Gets all the standard and private templates.
-
#list_default_templates_with_http_info(company_id, opts = {}) ⇒ Array<(ListTemplatesResponse, Integer, Hash)>
List Default Templates Gets all the standard and private templates.
-
#modify_payment_account(company_id, payment_account_id, opts = {}) ⇒ ModifyPaymentAccountResponse
Modify Payment Account Modifies the specified payment account.
-
#modify_payment_account_with_http_info(company_id, payment_account_id, opts = {}) ⇒ Array<(ModifyPaymentAccountResponse, Integer, Hash)>
Modify Payment Account Modifies the specified payment account.
-
#modify_payment_method(company_id, payment_method_id, opts = {}) ⇒ ModifyPaymentMethodResponse
Modify Payment Method Modifies the specified payment method.
-
#modify_payment_method_with_http_info(company_id, payment_method_id, opts = {}) ⇒ Array<(ModifyPaymentMethodResponse, Integer, Hash)>
Modify Payment Method Modifies the specified payment method.
-
#modify_vat_type(company_id, vat_type_id, opts = {}) ⇒ ModifyVatTypeResponse
Modify Vat Type Modifies the specified vat type.
-
#modify_vat_type_with_http_info(company_id, vat_type_id, opts = {}) ⇒ Array<(ModifyVatTypeResponse, Integer, Hash)>
Modify Vat Type Modifies the specified vat type.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SettingsApi
Returns a new instance of SettingsApi.
19 20 21 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_payment_account(company_id, opts = {}) ⇒ CreatePaymentAccountResponse
Create Payment Account Creates a new payment account.
28 29 30 31 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 28 def create_payment_account(company_id, opts = {}) data, _status_code, _headers = create_payment_account_with_http_info(company_id, opts) data end |
#create_payment_account_with_http_info(company_id, opts = {}) ⇒ Array<(CreatePaymentAccountResponse, Integer, Hash)>
Create Payment Account Creates a new payment account.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 39 def create_payment_account_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.create_payment_account ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.create_payment_account" end # resource path local_var_path = '/c/{company_id}/settings/payment_accounts'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_payment_account_request']) # return_type return_type = opts[:debug_return_type] || 'CreatePaymentAccountResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.create_payment_account", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#create_payment_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_payment_method(company_id, opts = {}) ⇒ CreatePaymentMethodResponse
Create Payment Method Creates a new payment method.
98 99 100 101 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 98 def create_payment_method(company_id, opts = {}) data, _status_code, _headers = create_payment_method_with_http_info(company_id, opts) data end |
#create_payment_method_with_http_info(company_id, opts = {}) ⇒ Array<(CreatePaymentMethodResponse, Integer, Hash)>
Create Payment Method Creates a new payment method.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 109 def create_payment_method_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.create_payment_method ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.create_payment_method" end # resource path local_var_path = '/c/{company_id}/settings/payment_methods'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_payment_method_request']) # return_type return_type = opts[:debug_return_type] || 'CreatePaymentMethodResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.create_payment_method", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#create_payment_method\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_vat_type(company_id, opts = {}) ⇒ CreateVatTypeResponse
Create Vat Type Creates a vat type.
168 169 170 171 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 168 def create_vat_type(company_id, opts = {}) data, _status_code, _headers = create_vat_type_with_http_info(company_id, opts) data end |
#create_vat_type_with_http_info(company_id, opts = {}) ⇒ Array<(CreateVatTypeResponse, Integer, Hash)>
Create Vat Type Creates a vat type.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 179 def create_vat_type_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.create_vat_type ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.create_vat_type" end # resource path local_var_path = '/c/{company_id}/settings/vat_types'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_vat_type_request']) # return_type return_type = opts[:debug_return_type] || 'CreateVatTypeResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.create_vat_type", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#create_vat_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_payment_account(company_id, payment_account_id, opts = {}) ⇒ nil
Delete Payment Account Deletes the specified payment account.
238 239 240 241 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 238 def delete_payment_account(company_id, payment_account_id, opts = {}) delete_payment_account_with_http_info(company_id, payment_account_id, opts) nil end |
#delete_payment_account_with_http_info(company_id, payment_account_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Payment Account Deletes the specified payment account.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 249 def delete_payment_account_with_http_info(company_id, payment_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.delete_payment_account ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.delete_payment_account" end # verify the required parameter 'payment_account_id' is set if @api_client.config.client_side_validation && payment_account_id.nil? fail ArgumentError, "Missing the required parameter 'payment_account_id' when calling SettingsApi.delete_payment_account" end # resource path local_var_path = '/c/{company_id}/settings/payment_accounts/{payment_account_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)).sub('{' + 'payment_account_id' + '}', CGI.escape(payment_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.delete_payment_account", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#delete_payment_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_payment_method(company_id, payment_method_id, opts = {}) ⇒ nil
Delete Payment Method Deletes the specified payment method.
307 308 309 310 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 307 def delete_payment_method(company_id, payment_method_id, opts = {}) delete_payment_method_with_http_info(company_id, payment_method_id, opts) nil end |
#delete_payment_method_with_http_info(company_id, payment_method_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Payment Method Deletes the specified payment method.
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 318 def delete_payment_method_with_http_info(company_id, payment_method_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.delete_payment_method ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.delete_payment_method" end # verify the required parameter 'payment_method_id' is set if @api_client.config.client_side_validation && payment_method_id.nil? fail ArgumentError, "Missing the required parameter 'payment_method_id' when calling SettingsApi.delete_payment_method" end # resource path local_var_path = '/c/{company_id}/settings/payment_methods/{payment_method_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)).sub('{' + 'payment_method_id' + '}', CGI.escape(payment_method_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.delete_payment_method", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#delete_payment_method\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_vat_type(company_id, vat_type_id, opts = {}) ⇒ nil
Delete Vat Type Deletes the specified vat type.
376 377 378 379 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 376 def delete_vat_type(company_id, vat_type_id, opts = {}) delete_vat_type_with_http_info(company_id, vat_type_id, opts) nil end |
#delete_vat_type_with_http_info(company_id, vat_type_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete Vat Type Deletes the specified vat type.
387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 387 def delete_vat_type_with_http_info(company_id, vat_type_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.delete_vat_type ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.delete_vat_type" end # verify the required parameter 'vat_type_id' is set if @api_client.config.client_side_validation && vat_type_id.nil? fail ArgumentError, "Missing the required parameter 'vat_type_id' when calling SettingsApi.delete_vat_type" end # resource path local_var_path = '/c/{company_id}/settings/vat_types/{vat_type_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)).sub('{' + 'vat_type_id' + '}', CGI.escape(vat_type_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.delete_vat_type", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#delete_vat_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_payment_account(company_id, payment_account_id, opts = {}) ⇒ GetPaymentAccountResponse
Get Payment Account Gets the specified payment account.
447 448 449 450 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 447 def get_payment_account(company_id, payment_account_id, opts = {}) data, _status_code, _headers = get_payment_account_with_http_info(company_id, payment_account_id, opts) data end |
#get_payment_account_with_http_info(company_id, payment_account_id, opts = {}) ⇒ Array<(GetPaymentAccountResponse, Integer, Hash)>
Get Payment Account Gets the specified payment account.
460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 460 def get_payment_account_with_http_info(company_id, payment_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.get_payment_account ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.get_payment_account" end # verify the required parameter 'payment_account_id' is set if @api_client.config.client_side_validation && payment_account_id.nil? fail ArgumentError, "Missing the required parameter 'payment_account_id' when calling SettingsApi.get_payment_account" end allowable_values = ["basic", "detailed", "fic_view"] if @api_client.config.client_side_validation && opts[:'fieldset'] && !allowable_values.include?(opts[:'fieldset']) fail ArgumentError, "invalid value for \"fieldset\", must be one of #{allowable_values}" end # resource path local_var_path = '/c/{company_id}/settings/payment_accounts/{payment_account_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)).sub('{' + 'payment_account_id' + '}', CGI.escape(payment_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? query_params[:'fieldset'] = opts[:'fieldset'] if !opts[:'fieldset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetPaymentAccountResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.get_payment_account", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#get_payment_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_payment_method(company_id, payment_method_id, opts = {}) ⇒ GetPaymentMethodResponse
Get Payment Method Gets the specified payment method.
526 527 528 529 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 526 def get_payment_method(company_id, payment_method_id, opts = {}) data, _status_code, _headers = get_payment_method_with_http_info(company_id, payment_method_id, opts) data end |
#get_payment_method_with_http_info(company_id, payment_method_id, opts = {}) ⇒ Array<(GetPaymentMethodResponse, Integer, Hash)>
Get Payment Method Gets the specified payment method.
539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 539 def get_payment_method_with_http_info(company_id, payment_method_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.get_payment_method ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.get_payment_method" end # verify the required parameter 'payment_method_id' is set if @api_client.config.client_side_validation && payment_method_id.nil? fail ArgumentError, "Missing the required parameter 'payment_method_id' when calling SettingsApi.get_payment_method" end allowable_values = ["basic", "detailed", "fic_view"] if @api_client.config.client_side_validation && opts[:'fieldset'] && !allowable_values.include?(opts[:'fieldset']) fail ArgumentError, "invalid value for \"fieldset\", must be one of #{allowable_values}" end # resource path local_var_path = '/c/{company_id}/settings/payment_methods/{payment_method_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)).sub('{' + 'payment_method_id' + '}', CGI.escape(payment_method_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? query_params[:'fieldset'] = opts[:'fieldset'] if !opts[:'fieldset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetPaymentMethodResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.get_payment_method", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#get_payment_method\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_tax_profile(company_id, opts = {}) ⇒ GetTaxProfileResponse
Get Tax Profile Gets the Tax Profile
602 603 604 605 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 602 def get_tax_profile(company_id, opts = {}) data, _status_code, _headers = get_tax_profile_with_http_info(company_id, opts) data end |
#get_tax_profile_with_http_info(company_id, opts = {}) ⇒ Array<(GetTaxProfileResponse, Integer, Hash)>
Get Tax Profile Gets the Tax Profile
612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 612 def get_tax_profile_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.get_tax_profile ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.get_tax_profile" end # resource path local_var_path = '/c/{company_id}/settings/tax_profile'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetTaxProfileResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.get_tax_profile", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#get_tax_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_template(company_id, template_id, opts = {}) ⇒ GetTemplatesResponse
Get Template Gets a specified template.
668 669 670 671 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 668 def get_template(company_id, template_id, opts = {}) data, _status_code, _headers = get_template_with_http_info(company_id, template_id, opts) data end |
#get_template_with_http_info(company_id, template_id, opts = {}) ⇒ Array<(GetTemplatesResponse, Integer, Hash)>
Get Template Gets a specified template.
681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 681 def get_template_with_http_info(company_id, template_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.get_template ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.get_template" end # verify the required parameter 'template_id' is set if @api_client.config.client_side_validation && template_id.nil? fail ArgumentError, "Missing the required parameter 'template_id' when calling SettingsApi.get_template" end allowable_values = ["basic", "detailed", "fic_view"] if @api_client.config.client_side_validation && opts[:'fieldset'] && !allowable_values.include?(opts[:'fieldset']) fail ArgumentError, "invalid value for \"fieldset\", must be one of #{allowable_values}" end # resource path local_var_path = '/c/{company_id}/settings/templates/{template_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)).sub('{' + 'template_id' + '}', CGI.escape(template_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? query_params[:'fieldset'] = opts[:'fieldset'] if !opts[:'fieldset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetTemplatesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.get_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#get_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_vat_type(company_id, vat_type_id, opts = {}) ⇒ GetVatTypeResponse
Get Vat Type Gets the specified vat type.
745 746 747 748 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 745 def get_vat_type(company_id, vat_type_id, opts = {}) data, _status_code, _headers = get_vat_type_with_http_info(company_id, vat_type_id, opts) data end |
#get_vat_type_with_http_info(company_id, vat_type_id, opts = {}) ⇒ Array<(GetVatTypeResponse, Integer, Hash)>
Get Vat Type Gets the specified vat type.
756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 756 def get_vat_type_with_http_info(company_id, vat_type_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.get_vat_type ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.get_vat_type" end # verify the required parameter 'vat_type_id' is set if @api_client.config.client_side_validation && vat_type_id.nil? fail ArgumentError, "Missing the required parameter 'vat_type_id' when calling SettingsApi.get_vat_type" end # resource path local_var_path = '/c/{company_id}/settings/vat_types/{vat_type_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)).sub('{' + 'vat_type_id' + '}', CGI.escape(vat_type_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetVatTypeResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.get_vat_type", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#get_vat_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_default_templates(company_id, opts = {}) ⇒ ListTemplatesResponse
List Default Templates Gets all the standard and private templates.
815 816 817 818 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 815 def list_default_templates(company_id, opts = {}) data, _status_code, _headers = list_default_templates_with_http_info(company_id, opts) data end |
#list_default_templates_with_http_info(company_id, opts = {}) ⇒ Array<(ListTemplatesResponse, Integer, Hash)>
List Default Templates Gets all the standard and private templates.
827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 827 def list_default_templates_with_http_info(company_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.list_default_templates ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.list_default_templates" end allowable_values = ["basic", "detailed", "fic_view"] if @api_client.config.client_side_validation && opts[:'fieldset'] && !allowable_values.include?(opts[:'fieldset']) fail ArgumentError, "invalid value for \"fieldset\", must be one of #{allowable_values}" end # resource path local_var_path = '/c/{company_id}/settings/templates'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = opts[:'fields'] if !opts[:'fields'].nil? query_params[:'fieldset'] = opts[:'fieldset'] if !opts[:'fieldset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListTemplatesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.list_default_templates", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#list_default_templates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#modify_payment_account(company_id, payment_account_id, opts = {}) ⇒ ModifyPaymentAccountResponse
Modify Payment Account Modifies the specified payment account.
888 889 890 891 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 888 def modify_payment_account(company_id, payment_account_id, opts = {}) data, _status_code, _headers = modify_payment_account_with_http_info(company_id, payment_account_id, opts) data end |
#modify_payment_account_with_http_info(company_id, payment_account_id, opts = {}) ⇒ Array<(ModifyPaymentAccountResponse, Integer, Hash)>
Modify Payment Account Modifies the specified payment account.
900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 900 def modify_payment_account_with_http_info(company_id, payment_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.modify_payment_account ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.modify_payment_account" end # verify the required parameter 'payment_account_id' is set if @api_client.config.client_side_validation && payment_account_id.nil? fail ArgumentError, "Missing the required parameter 'payment_account_id' when calling SettingsApi.modify_payment_account" end # resource path local_var_path = '/c/{company_id}/settings/payment_accounts/{payment_account_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)).sub('{' + 'payment_account_id' + '}', CGI.escape(payment_account_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'modify_payment_account_request']) # return_type return_type = opts[:debug_return_type] || 'ModifyPaymentAccountResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.modify_payment_account", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#modify_payment_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#modify_payment_method(company_id, payment_method_id, opts = {}) ⇒ ModifyPaymentMethodResponse
Modify Payment Method Modifies the specified payment method.
964 965 966 967 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 964 def modify_payment_method(company_id, payment_method_id, opts = {}) data, _status_code, _headers = modify_payment_method_with_http_info(company_id, payment_method_id, opts) data end |
#modify_payment_method_with_http_info(company_id, payment_method_id, opts = {}) ⇒ Array<(ModifyPaymentMethodResponse, Integer, Hash)>
Modify Payment Method Modifies the specified payment method.
976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 976 def modify_payment_method_with_http_info(company_id, payment_method_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.modify_payment_method ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.modify_payment_method" end # verify the required parameter 'payment_method_id' is set if @api_client.config.client_side_validation && payment_method_id.nil? fail ArgumentError, "Missing the required parameter 'payment_method_id' when calling SettingsApi.modify_payment_method" end # resource path local_var_path = '/c/{company_id}/settings/payment_methods/{payment_method_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)).sub('{' + 'payment_method_id' + '}', CGI.escape(payment_method_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'modify_payment_method_request']) # return_type return_type = opts[:debug_return_type] || 'ModifyPaymentMethodResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.modify_payment_method", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#modify_payment_method\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#modify_vat_type(company_id, vat_type_id, opts = {}) ⇒ ModifyVatTypeResponse
Modify Vat Type Modifies the specified vat type.
1040 1041 1042 1043 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 1040 def modify_vat_type(company_id, vat_type_id, opts = {}) data, _status_code, _headers = modify_vat_type_with_http_info(company_id, vat_type_id, opts) data end |
#modify_vat_type_with_http_info(company_id, vat_type_id, opts = {}) ⇒ Array<(ModifyVatTypeResponse, Integer, Hash)>
Modify Vat Type Modifies the specified vat type.
1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 |
# File 'lib/fattureincloud_ruby_sdk/api/settings_api.rb', line 1052 def modify_vat_type_with_http_info(company_id, vat_type_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettingsApi.modify_vat_type ...' end # verify the required parameter 'company_id' is set if @api_client.config.client_side_validation && company_id.nil? fail ArgumentError, "Missing the required parameter 'company_id' when calling SettingsApi.modify_vat_type" end # verify the required parameter 'vat_type_id' is set if @api_client.config.client_side_validation && vat_type_id.nil? fail ArgumentError, "Missing the required parameter 'vat_type_id' when calling SettingsApi.modify_vat_type" end # resource path local_var_path = '/c/{company_id}/settings/vat_types/{vat_type_id}'.sub('{' + 'company_id' + '}', CGI.escape(company_id.to_s)).sub('{' + 'vat_type_id' + '}', CGI.escape(vat_type_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'modify_vat_type_request']) # return_type return_type = opts[:debug_return_type] || 'ModifyVatTypeResponse' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2AuthenticationCodeFlow'] = opts.merge( :operation => :"SettingsApi.modify_vat_type", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettingsApi#modify_vat_type\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |